@@ -27,6 +27,7 @@ class FFile:
 		if self.__file_exists():
 			with open(self.nomeFile, 'r') as fr:
 				self.string_ = fr.read()
+			return self.string_
 		else:
 			print("File not exists")
 
@@ -35,6 +36,7 @@ class FFile:
 		if self.__file_exists():
 			self.read_file()
 			self.json_ = json.loads(self.string_)
+			return self.json_
 		else:
 			print("File not exists")
 
